==> scala-k8s-objects_2.13-0.2.0-sources.jar: io/k8s/api/core/v1/Endpoints.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s._

/** Endpoints is a collection of endpoints that implement the actual service. Example:

	 Name: "mysvc",
	 Subsets: [
	   {
	     Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
	     Ports: [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
	   },
	   {
	     Addresses: [{"ip": "10.10.3.3"}],
	     Ports: [{"name": "a", "port": 93}, {"name": "b", "port": 76}]
	   },
	] */
final case class Endpoints(
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None,
  subsets : Option[Seq[io.k8s.api.core.v1.EndpointSubset]] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("", "Endpoints", "v1")


  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : Endpoints = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : Endpoints = copy(metadata = metadata.map(f))

  /** Returns a new data with subsets set to new value */
  def withSubsets(value: Seq[io.k8s.api.core.v1.EndpointSubset]) : Endpoints = copy(subsets = Some(value))
  /** Appends new values to subsets */
  def addSubsets(newValues: io.k8s.api.core.v1.EndpointSubset*) : Endpoints = copy(subsets = Some(subsets.fold(newValues)(_ ++ newValues)))
  /** if subsets has a value, transforms to the result of function*/
  def mapSubsets(f: Seq[io.k8s.api.core.v1.EndpointSubset] => Seq[io.k8s.api.core.v1.EndpointSubset]) : Endpoints = copy(subsets = subsets.map(f))
}

==> scala-k8s-objects_3-0.5.1-sources.jar: io/k8s/api/core/v1/Endpoints.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** Endpoints is a collection of endpoints that implement the actual service. Example:

	 Name: "mysvc",
	 Subsets: [
	   {
	     Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
	     Ports: [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
	   },
	   {
	     Addresses: [{"ip": "10.10.3.3"}],
	     Ports: [{"name": "a", "port": 93}, {"name": "b", "port": 76}]
	   },
	] */
final case class Endpoints(
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None,
  subsets : Option[Seq[io.k8s.api.core.v1.EndpointSubset]] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("", "Endpoints", "v1")


  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : Endpoints = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : Endpoints = copy(metadata = metadata.map(f))

  /** Returns a new data with subsets set to new value */
  def withSubsets(value: Seq[io.k8s.api.core.v1.EndpointSubset]) : Endpoints = copy(subsets = Some(value))
  /** Appends new values to subsets */
  def addSubsets(newValues: io.k8s.api.core.v1.EndpointSubset*) : Endpoints = copy(subsets = Some(subsets.fold(newValues)(_ ++ newValues)))
  /** if subsets has a value, transforms to the result of function*/
  def mapSubsets(f: Seq[io.k8s.api.core.v1.EndpointSubset] => Seq[io.k8s.api.core.v1.EndpointSubset]) : Endpoints = copy(subsets = subsets.map(f))

  override def foldTo[T : Builder] : T = Endpoints.encoder.apply(this)
}

object Endpoints {

    implicit val encoder : Encoder[io.k8s.api.core.v1.Endpoints] = new Encoder[io.k8s.api.core.v1.Endpoints] {
        def apply[T : Builder](o: io.k8s.api.core.v1.Endpoints) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("metadata", o.metadata)
            .write("subsets", o.subsets)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit val decoder: Decoder[Endpoints] = new Decoder[Endpoints] {
      def apply[T : Reader](t: T): Either[String, Endpoints] = for {
          obj <- ObjectReader(t)
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta]("metadata")
          subsets <- obj.readOpt[Seq[io.k8s.api.core.v1.EndpointSubset]]("subsets")
      } yield Endpoints (
          metadata = metadata,
          subsets = subsets
        )
    }
}
